@@ -1020,3 +1020,10 @@ class OpenEVSE:
         if self._config is not None and "max_current_hard" in self._config:
             return self._config["max_current_hard"]
         return MAX_AMPS
+
+    @property
+    def mqtt_connected(self) -> bool:
+        """Return the status of the mqtt connection."""
+        if self._status is not None and "mqtt_connected" in self._status:
+            return self._status["mqtt_connected"]
+        return False
